Module emit

Module emit 

Public API for emit. Object-file emission.

Produces a minimal ELF-64, Mach-O 64-bit, or COFF relocatable object file containing a single .text section. The actual byte encoding is supplied by the target via the Emitter trait.

Structs

DebugLineRow
A single source mapping row for debug line table emission.
ObjectFile
Assembled object file ready to be written to disk or passed to a linker.
Reloc
A single relocation record.
Section
A named output section (.text, __TEXT,__text, etc.).
Symbol
A symbol definition.

Enums

ObjectFormat
Supported object-file formats.
RelocKind
Kind of relocation record.

Traits

Emitter
Implemented by each target to encode machine instructions into bytes.

Functions

emit_object
Build a complete ObjectFile from a MachineFunction using emitter.